@@ -2,6 +2,11 @@
 {-# LANGUAGE DeriveDataTypeable         #-}
 {-# LANGUAGE OverloadedStrings          #-}
 {-# LANGUAGE StandaloneDeriving         #-}
+
+#if __GLASGOW_HASKELL__ >= 806
+{-# LANGUAGE QuantifiedConstraints      #-}
+#endif
+
 {-|
 Module:      TextShow.Classes
 Copyright:   (C) 2014-2017 Ryan Scott
@@ -392,7 +397,11 @@ showbToShowtl sf = toLazyText . sf
 -- | Lifting of the 'TextShow' class to unary type constructors.
 --
 -- /Since: 2/
-class TextShow1 f where
+class
+#if __GLASGOW_HASKELL__ >= 806
+      (forall a. TextShow a => TextShow (f a)) =>
+#endif
+      TextShow1 f where
     -- | 'showbPrec' function for an application of the type constructor
     -- based on 'showbPrec' and 'showbList' functions for the argument type.
     --
@@ -457,7 +466,21 @@ liftShowtlPrec sp sl = showbPrecToShowtlPrec $ liftShowbPrec (showtlPrecToShowbP
 -- | Lifting of the 'TextShow' class to binary type constructors.
 --
 -- /Since: 2/
-class TextShow2 f where
+class
+#if __GLASGOW_HASKELL__ >= 806
+      ( forall a. TextShow a => TextShow1 (f a)
+# if __GLASGOW_HASKELL__ < 900
+      -- Sadly, pre-9.0 versions of GHC have difficulty inferring this
+      -- superclass from the one above due to
+      -- https://gitlab.haskell.org/ghc/ghc/-/issues/17202.
+      -- As a workaround, we manually expand the superclass above to assist
+      -- type inference. Without doing this, the text-show test suite would
+      -- not compile on pre-9.0 versions of GHC.
+      , forall a b. (TextShow a, TextShow b) => TextShow (f a b)
+# endif
+      ) =>
+#endif
+      TextShow2 f where
     -- | 'showbPrec' function for an application of the type constructor
     -- based on 'showbPrec' and 'showbList' functions for the argument types.
     --
