@@ -204,7 +204,9 @@ formatRealFloatAltB fmt decs alt x
           _ ->
            let
              (ei,is') = roundTo 1 is
-             n:_ = map i2d (if ei > 0 then init is' else is')
+             n = case map i2d (if ei > 0 then init is' else is') of
+                   n':_ -> n'
+                   []   -> error "formatRealFloatAltB (Exponent, negative decs): Unexpected empty list"
            in singleton n <> singleton 'e' <> decimal (e-1+ei)
        Just dec ->
         let dec' = max dec 1 in
@@ -213,7 +215,9 @@ formatRealFloatAltB fmt decs alt x
          _ ->
           let
            (ei,is') = roundTo (dec'+1) is
-           (d:ds') = map i2d (if ei > 0 then init is' else is')
+           (d,ds') = case map i2d (if ei > 0 then init is' else is') of
+                       (d':ds'') -> (d',ds'')
+                       []        -> error "formatRealFloatAltB (Exponent, non-negative decs): Unexpected empty list"
           in
           singleton d <> singleton '.' <> fromString ds' <> singleton 'e' <> decimal (e-1+ei)
      Fixed ->
@@ -241,7 +245,9 @@ formatRealFloatAltB fmt decs alt x
         else
          let
           (ei,is') = roundTo dec' (replicate (-e) 0 ++ is)
-          d:ds' = map i2d (if ei > 0 then is' else 0:is')
+          (d,ds') = case map i2d (if ei > 0 then is' else 0:is') of
+                      (d':ds'') -> (d',ds'')
+                      []        -> error "formatRealFloatAltB (Fixed): Unexpected empty list"
          in
          singleton d <> (if null ds' && not alt then "" else singleton '.' <> fromString ds')
 
@@ -355,7 +361,6 @@ floatToDigits x =
  (map fromIntegral (reverse rds), k)
 
 roundTo :: Int -> [Int] -> (Int,[Int])
-#if MIN_VERSION_base(4,6,0)
 roundTo d is =
   case f d True is of
     x@(0,_) -> x
@@ -374,22 +379,6 @@ roundTo d is =
        (c,ds) = f (n-1) (even i) xs
        i'     = c + i
   base = 10
-#else
-roundTo d is =
-  case f d is of
-    x@(0,_) -> x
-    (1,xs)  -> (1, 1:xs)
-    _       -> error "roundTo: bad Value"
- where
-  f n []     = (0, replicate n 0)
-  f 0 (x:_)  = (if x >= 5 then 1 else 0, [])
-  f n (i:xs)
-     | i' == 10  = (1,0:ds)
-     | otherwise = (0,i':ds)
-      where
-       (c,ds) = f (n-1) xs
-       i'     = c + i
-#endif
 
 -- Exponentiation with a cache for the most common numbers.
 
