@@ -1,6 +1,6 @@
-{-# LANGUAGE CPP               #-}
 {-# LANGUAGE OverloadedStrings #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-}
+
 {-|
 Module:      TextShow.Data.Ratio
 Copyright:   (C) 2014-2017 Ryan Scott
@@ -15,27 +15,16 @@ Portability: GHC
 -}
 module TextShow.Data.Ratio () where
 
-import Data.Monoid.Compat ((<>))
-
 import GHC.Real (Ratio(..), ratioPrec, ratioPrec1)
 
-import TextShow.Classes (TextShow(..), showbParen)
-#if MIN_VERSION_base(4,4,0)
-import TextShow.Classes (TextShow1(..))
-#endif
+import Prelude ()
+import Prelude.Compat
+
+import TextShow.Classes (TextShow(..), TextShow1(..), showbParen)
 import TextShow.Data.Integral ()
 
--- | Note that on @base-4.3.0.0@, this must have a @('TextShow' a, 'Integral' a)@
--- constraint instead of just a @('TextShow' a)@ constraint.
---
--- /Since: 2/
-instance
-#if MIN_VERSION_base(4,4,0)
-         TextShow a
-#else
-         (TextShow a, Integral a)
-#endif
-      => TextShow (Ratio a) where
+-- | /Since: 2/
+instance TextShow a => TextShow (Ratio a) where
     {-# SPECIALIZE instance TextShow Rational #-}
     showbPrec p (numer :% denom) = showbParen (p > ratioPrec) $
            showbPrec ratioPrec1 numer
@@ -43,14 +32,10 @@ instance
         <> showbPrec ratioPrec1 denom
     {-# INLINE showbPrec #-}
 
-#if MIN_VERSION_base(4,4,0)
--- | Only available with @base-4.4.0.0@ or later.
---
--- /Since: 2/
+-- | /Since: 2/
 instance TextShow1 Ratio where
     liftShowbPrec sp _ p (numer :% denom) = showbParen (p > ratioPrec) $
            sp ratioPrec1 numer
         <> " % "
         <> sp ratioPrec1 denom
     {-# INLINE liftShowbPrec #-}
-#endif
