@@ -1,9 +1,5 @@
 {-# LANGUAGE CPP #-}
-
-#if __GLASGOW_HASKELL__ >= 706
 {-# LANGUAGE PolyKinds #-}
-#endif
-
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 
 {-|
@@ -18,7 +14,6 @@ Portability: GHC
 -}
 module Instances.Data.Type.Coercion () where
 
-#if MIN_VERSION_base(4,7,0)
 import Data.Coerce (Coercible)
 import Data.Type.Coercion (Coercion(..))
 
@@ -26,4 +21,3 @@ import Test.QuickCheck (Arbitrary(..), arbitraryBoundedEnum)
 
 instance Coercible a b => Arbitrary (Coercion a b) where
     arbitrary = arbitraryBoundedEnum
-#endif
