@@ -20,7 +20,7 @@ import Prelude.Compat
 import Test.Hspec (Spec, hspec, parallel)
 
 #if MIN_VERSION_base(4,8,1)
-import Data.Proxy (Proxy(..))
+import Data.Proxy.Compat (Proxy(..))
 import GHC.Stack (CallStack)
 # if MIN_VERSION_base(4,9,0)
 import GHC.Stack (SrcLoc)
